@@ -143,6 +143,20 @@ class DirectusApi:
         response = requests.delete(url, headers=headers)
         return response
 
+    def delete_items(self, collection: str, ids: list) -> Response:
+        """
+        Delete multiple items by id.
+        Make a DELETE-Request to /items/<collection_name> and return the response as JSON.
+        """
+        url = self.endpoint + '/items/' + collection
+        headers = {
+            'Authorization': 'Bearer ' + self.access_token,
+            'Content-Type': 'application/json',
+            'Accept': 'application/json'
+        }
+        response = requests.delete(url, json=ids, headers=headers)
+        return response
+
     def delete_all_items_from_collection(self, collection: str):
         """
         Delete all items from a collection.
